# rym-cx

[![PyPI - Version](https://img.shields.io/pypi/v/rym-token.svg)](https://pypi.org/project/rym-cx)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/rym-token.svg)](https://pypi.org/project/rym-cx)
[![License: MIT](https://img.shields.io/badge/license-MIT-C06524)](https://github.com/muppetjones/rym-py/blob/main/LICENSE.txt)

> [!IMPORTANT]  
> This is a WIP and is not intended for general use.

An ECS implementation in python. This package is a proof of concept and is not
intended to provide a fully featured ECS. For a description of the goals and concepts
used in this project, see the [design docs](/docs/design).

## Testing

Run one of the following to execute tests:

```shell
pdm test
```

```shell
python -m unittest discover -vv tests.rym.cx
```
